@@ -702,320 +702,3 @@ def compute_alpha_metrics(data_df = None, core_tokens=['BTC', 'ETH'], extra_toke
 
     return payload_message
 
-
-def compute_alpha_monthly_metrics(data_df = None, core_tokens=['BTC', 'ETH'], extra_tokens=['AVAX'], moderating_factor = 0.1, frequency='weekly', generate_kpis = True, plot_html=True, stop_loss_quantile = 0.75,take_profit_quantile = 0.75,write_excel_file = True, local_root_directory = None, plot_metrics = True,plot_html_save = True):
-    ssjs = core_tokens + extra_tokens
-    universe_literal = '_'.join(ssjs)
-    if plot_html:
-        title = f'HedgeFarm Strategy Universe {universe_literal} moderating factor {moderating_factor}'
-        backtest_df = data_df[['COMBO_STRAT']].copy()
-        backtest_df.columns = ['strategy']
-        fig = realtime_plotting_utility.plot_multiple_time_series(
-            data_df=backtest_df,
-            logy=True, split=False,
-            put_on_same_scale=False,
-            title=title)
-        fig.show()
-    # KPI writing
-
-
-    if generate_kpis:
-        riskmetrics.compute_plot_excel_kpis_meterics_metrics(backtest_df, title,
-                                                             local_root_directory, plot_html=True,
-                                                             write_file=True)
-        btd_kpis, ytd_kpis, past_returns = riskmetrics.compute_extensive_kpis(
-            data_df=data_df.copy(), strat='COMBO_STRAT')
-
-        go_comp_kpi = lambda x: compute_metrics(x, strat=me_strat)
-
-
-        def compute_allocation(row_df, universe=None):
-            compo = {}
-            for me_token in universe:
-                compo[me_token] = row_df[f'SF{me_token}']
-            return compo
-
-
-        comp_alloc = lambda x: compute_allocation(x, universe=ssjs)
-        data_df['COMBO_STRAT_compo'] = data_df.apply(comp_alloc, axis=1)
-
-        ############# strategy drawdown
-        dd_data_df = data_df.copy() #pd.merge(merged_df.copy(), sol_ohlc_df.copy(), left_index=True,
-                              #right_index=True)
-        limited_dd_data_df = dd_data_df[dd_data_df.index >= '2021-04-01'].copy()
-        limited_dd_data_df = limited_dd_data_df[limited_dd_data_df.index <= '2021-07-01'].copy()
-
-        dd_list = []
-        for me_underlying in [f'close_{ssj}' for ssj in ['BTC'] + extra_tokens  ] + ['COMBO_STRAT']:
-            dd_display_name = 'drawdown ' + me_underlying.replace('close_', '')
-            dd_list.append(dd_display_name)
-            ### whole period drawdown
-            dd_norm_strat = riskmetrics.drawdown(dd_data_df[me_underlying])
-            # merged_df[f'drawdown_{me_underlying}'] = dd_norm_strat
-
-            dd_data_df[dd_display_name] = - dd_norm_strat
-            ### limited_period_drawdown
-            limited_dd_norm_strat = riskmetrics.drawdown(limited_dd_data_df[me_underlying])
-            # merged_df[f'drawdown_{me_underlying}'] = dd_norm_strat
-            dd_display_name = 'drawdown ' + me_underlying.replace('close_', '')
-            limited_dd_data_df[dd_display_name] = - limited_dd_norm_strat
-
-
-
-        if plot_html_save:
-            dd_dic = {}
-            for me_under in extra_tokens:
-                dd_dic[f'drawdown {me_under}'] = me_under
-
-
-            new_names = {'drawdown BTC': 'Bitcoin', 'drawdown COMBO_STRAT': 'Absolute Return DeFi Strategy'}
-
-            new_names.update(dd_dic)
-
-            dd_data_df = dd_data_df.rename(columns=new_names)
-            fig = realtime_plotting_utility.plot_multiple_drawdowns(dd_data_df,
-                                                                    list(new_names.values()))
-            fig.show()
-
-            limited_dd_data_df = limited_dd_data_df.rename(columns=new_names)
-            fig = realtime_plotting_utility.plot_multiple_drawdowns(limited_dd_data_df,
-                                                                    list(new_names.values()))
-            fig.show()
-
-            dollar_df = data_df[['DOLLAR_COMBO_STRAT']].copy()
-            new_names = {'DOLLAR_COMBO_STRAT': 'Absolute Return DeFi Strategy'}
-            dollar_df = dollar_df.rename(columns=new_names)
-            fig = realtime_plotting_utility.plot_dollar_multiple_time_series(data_df=dollar_df,
-                                                                             logy=True, split=False,
-                                                                             put_on_same_scale=False,
-                                                                             title=f'performance (exposition moderating factor {moderating_factor}  rebalancing {frequency})')
-            fig.show()
-
-            fig = realtime_plotting_utility.plot_multiple_time_series(
-                data_df=data_df[['long_expo', 'short_expo']],
-                logy=False, split=False,
-                put_on_same_scale=False,
-                title=f'long/short exposition (exposition moderating factor {moderating_factor}  rebalancing {frequency})')
-            fig.show()
-
-        print('computing KPIs per epoch')
-
-        me_strat = 'COMBO_STRAT'
-        whole_period_kpi_df = riskmetrics.get_kpi(data_df[[me_strat]])
-        whole_period_kpi_df = whole_period_kpi_df.iloc[1:]
-
-        kpi_df = riskmetrics.get_kpi(data_df[[me_strat]])
-        stub = f'mf_{moderating_factor}_strat_{me_strat}'
-        kpi_df.columns = [stub]
-        to_store_df = data_df.copy()
-        to_store_df['Date'] = to_store_df.index
-
-        #### new fresh weights on monday
-        to_store_df['has_just_rebalanced'] = to_store_df.index.weekday == 0
-
-        to_store_df['weekly_epoch_number'] = to_store_df['has_just_rebalanced'].cumsum()
-
-        def monthlize_epoch(row):
-            weekly_epoch_number = row['weekly_epoch_number']
-            epoch_number = weekly_epoch_number-weekly_epoch_number%4
-            return epoch_number
-
-        to_store_df['epoch_number'] = to_store_df.apply(monthlize_epoch, axis = 1)
-        to_store_df['epoch_number_diff'] = to_store_df['epoch_number'].diff()
-        to_store_df['has_just_rebalanced'] = to_store_df['epoch_number_diff'] >0
-
-        epoch_df = to_store_df[to_store_df['has_just_rebalanced']].copy()
-        epoch_df = epoch_df[
-            ['epoch_number', me_strat, 'long_expo', 'short_expo', f'{me_strat}_compo']]
-
-
-        def compute_metrics(df, strat=None):
-            kpi_df = riskmetrics.get_kpi(df[[strat]])
-            return kpi_df.to_dict()[strat]
-
-
-        go_comp_kpi = lambda x: compute_metrics(x, strat=me_strat)
-
-        epochkpis_df = to_store_df[['epoch_number', me_strat]].groupby(['epoch_number']).apply(
-            go_comp_kpi)
-        epochkpis_df = epochkpis_df.sort_index()
-        epochkpis_df = pd.DataFrame.from_records(epochkpis_df.to_dict()).T
-        final_df = pd.merge(epoch_df.copy(), epochkpis_df.copy(), left_on='epoch_number',
-                            right_index=True)
-        final_df = final_df.drop(columns=[me_strat])
-        final_df = final_df.rename(columns={f'{me_strat}_compo': 'COMPO'})
-
-        final_df['STRAT'] = me_strat
-        final_df['STRATPARAMS'] = f'{me_strat}_{moderating_factor}'
-        # final_df['frequency'] = frequency
-        # final_df['moderation'] = moderating_factor
-        # if moderating_factor >0.5:
-        #     final_df['subscription_asset'] = me_strat.replace('STRAT','').replace('_','')
-        # else:
-        #     final_df['subscription_asset'] = 'USDC'
-        final_df['subscription_asset'] = 'USDC'
-        final_df['date'] = final_df.index
-
-        freq_aggregated_df = final_df.copy()
-        freq_aggregated_df = freq_aggregated_df.sort_values(by='epoch_number')
-        # freq_aggregated_df.index = freq_aggregated_df.index.tz_localize(None)
-
-        av_dd_df = freq_aggregated_df.groupby(['STRATPARAMS'])['mdd'].quantile(q=stop_loss_quantile)
-        qt_gain_df = freq_aggregated_df.groupby(['STRATPARAMS'])['simple_return'].quantile(
-            q=take_profit_quantile)
-
-        av_dd_df = av_dd_df.to_frame()
-        qt_gain_df = qt_gain_df.to_frame()
-
-        av_dd_df.columns = ['stop loss']
-        qt_gain_df.columns = ['take profit']
-        av_dd_df = av_dd_df.round(decimals=2)
-        qt_gain_df = qt_gain_df.round(decimals=2)
-
-        from sklearn.preprocessing import KBinsDiscretizer
-
-
-        def categorize(data_df=None, column_to_categorize=None):
-            est = KBinsDiscretizer(n_bins=3, encode='ordinal', strategy='uniform')
-            est.fit(abs(data_df[column_to_categorize].values.reshape(-1, 1)))
-            binarized_data = est.transform(abs(data_df[column_to_categorize].values.reshape(-1, 1)))
-            data_df[column_to_categorize + '_rank'] = binarized_data
-            return data_df.copy()
-
-
-        av_dd_df_categorized = categorize(data_df=av_dd_df, column_to_categorize='stop loss')
-
-        freq_aggregated_df = pd.merge(freq_aggregated_df.copy(), av_dd_df.copy(),
-                                      left_on='STRATPARAMS', right_index=True)
-        freq_aggregated_df = pd.merge(freq_aggregated_df.copy(), qt_gain_df.copy(),
-                                      left_on='STRATPARAMS', right_index=True)
-
-        ######## computing metrics around strats and epochs
-        freq_aggregated_df = freq_aggregated_df.rename(columns={
-            'date': 'date',
-            'epoch_number': 'epoch',
-            'long_expo': 'long risk allocation',
-            'short_expo': 'short risk allocation',
-            'COMPO': 'composition',
-            'simple_return': 'epoch realized return',
-            'annual_return': 'epoch realized annualized return',
-            'annual_volatility': 'epoch realized annualized volatility',
-            'sharpe': 'epoch realized sharpe ratio',
-            'calmar': 'epoch realized calmar ratio',
-            'mdd': 'epoch realized max drawdown',
-            'STRAT': 'strategy',
-            'STRATPARAMS': 'strategy parameters',
-            'subscription_asset': 'subscription asset'})
-        freq_aggregated_df = freq_aggregated_df[
-            ['date', 'strategy', 'strategy parameters', 'subscription asset', 'composition',
-             'epoch', 'long risk allocation', 'short risk allocation', 'stop loss', 'take profit',
-             'epoch realized return', 'epoch realized annualized return',
-             'epoch realized annualized volatility',
-             'epoch realized sharpe ratio', 'epoch realized calmar ratio',
-             'epoch realized max drawdown']]
-
-        freq_aggregated_df = freq_aggregated_df.sort_values(by='epoch')
-
-        freq_aggregated_df['epochs compounded return'] = np.cumprod(1+freq_aggregated_df['epoch realized return'].values )
-
-
-        new_epoch_details = freq_aggregated_df.iloc[-1].copy()
-        new_epoch_details_dict = new_epoch_details.to_dict()
-        new_epoch_details_dict['date'] = str(new_epoch_details_dict['date'])
-
-        compo_dic = new_epoch_details_dict['composition']
-        clean_compo = {}
-        for key, value in compo_dic.items():
-            clean_compo[key] = f'{round(value * 100, 2)}%'
-
-        new_epoch_details_dict['composition'] = clean_compo
-
-        payload_message = json.dumps(new_epoch_details_dict)
-
-        payload_message = payload_message.replace('"', '')
-
-        date = new_epoch_details_dict['date']
-        strat = new_epoch_details_dict['strategy']
-        params = new_epoch_details_dict['strategy parameters']
-        sub_ass = new_epoch_details_dict['subscription asset']
-        composition = new_epoch_details_dict['composition']
-        epoch = new_epoch_details_dict['epoch']
-        lr = new_epoch_details_dict['long risk allocation']
-        sr = new_epoch_details_dict['short risk allocation']
-        sl = new_epoch_details_dict['stop loss']
-        tp = new_epoch_details_dict['take profit']
-
-
-        if plot_metrics:
-            to_plot_df = freq_aggregated_df[
-                ['epoch realized return', 'epoch realized max drawdown']].copy()
-            fig = realtime_plotting_utility.plot_multiple_bar_series(
-                data_df=to_plot_df[['epoch realized return']] * 100.,
-                logy=False, split=False,
-                put_on_same_scale=False,
-                title=f'epoch realized return in percent (exposition moderating factor {moderating_factor}  epoch frequency {frequency})')
-            fig.show()
-            fig = realtime_plotting_utility.plot_multiple_bar_series(
-                data_df=to_plot_df[['epoch realized max drawdown']] * 100.,
-                logy=False, split=False,
-                put_on_same_scale=False,
-                title=f'epoch realized max drawdown in percent (exposition moderating factor {moderating_factor}  epoch frequency {frequency})')
-            fig.show()
-        freq_aggregated_df['year'] = freq_aggregated_df.index.year
-        freq_aggregated_df['month'] = freq_aggregated_df.index.month
-
-
-        def rename_month(row):
-            if row['month'] == 1:
-                return 'January'
-            if row['month'] == 2:
-                return 'February'
-            if row['month'] == 3:
-                return 'March'
-            if row['month'] == 4:
-                return 'April'
-            if row['month'] == 5:
-                return 'May'
-            if row['month'] == 6:
-                return 'June'
-            if row['month'] == 7:
-                return 'July'
-            if row['month'] == 8:
-                return 'August'
-            if row['month'] == 9:
-                return 'September'
-            if row['month'] == 10:
-                return 'October'
-            if row['month'] == 11:
-                return 'November'
-            if row['month'] == 12:
-                return 'December'
-
-        freq_aggregated_df['month'] = freq_aggregated_df.apply(rename_month, axis=1)
-        freq_aggregated_df = freq_aggregated_df.set_index(['year', 'month'])
-        freq_aggregated_df = freq_aggregated_df.drop(columns=['date', 'epoch'])
-
-
-
-        if write_excel_file:
-            writer = pd.ExcelWriter(local_root_directory + f'{universe_literal}_monthly_ls_epochs_details_ls.xlsx',
-                                    engine='xlsxwriter')
-            freq_aggregated_df.to_excel(writer, sheet_name='epoch')
-            writer.save()
-
-            writer = pd.ExcelWriter(
-                local_root_directory + f'{universe_literal}_monthly_kpi_df_ls_strategy.xlsx',
-                engine='xlsxwriter')
-            # whole_period_kpi_df.to_excel(writer, sheet_name=frequency)
-            btd_kpis = btd_kpis.to_frame()
-            btd_kpis.columns = [me_strat]
-            past_returns = past_returns.to_frame()
-            past_returns.columns = [me_strat]
-
-            btd_kpis.to_excel(writer, sheet_name='advanced_btd')
-            ytd_kpis.to_excel(writer, sheet_name='advanced_ytd')
-            past_returns.to_excel(writer, sheet_name='common')
-            writer.save()
-
-    return payload_message
-
