@@ -11,7 +11,7 @@ import math
 import pandas as pd
 from scipy.optimize import Bounds, LinearConstraint, minimize
 from cryptotoolbox.realtime import realtime_plotting_utility
-
+from datetime import datetime
 import numpy as np
 
 # Internal packages
@@ -758,7 +758,8 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
             daily_df['year'] = daily_df.index.year
             daily_df['month'] = daily_df.index.month
             def get_month_date(row):
-                return datetime(year=row['year'], month=row['month'])
+                from datetime import datetime
+                return datetime(year=int(row['year']), month=int(row['month']), day=1)
 
             daily_df['month_date'] = daily_df.apply(get_month_date, axis = 1)
 
